( cd opt/kde/share/doc/HTML/nn/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/klipper ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
( cd opt/kde/share/doc/HTML/nn/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/nn/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/nn/common common )
